/// <reference types="node" />
/// <reference types="node" />
/// <reference types="node" />
import { Readable } from 'stream';
import * as fse from 'fs-extra';
import { RPCService } from '@opensumi/ide-connection';
import { DisposableCollection, Event, IDisposable, IFileStatOptions, IReadFileStreamOptions, Uri, UriComponents } from '@opensumi/ide-core-node';
import { DidFilesChangedParams, FileChangeEvent, FileMoveOptions, FileStat, FileSystemProviderCapabilities, FileType, IDiskFileProvider } from '../common/';
export interface IRPCDiskFileSystemProvider {
    onDidFilesChanged(event: DidFilesChangedParams): void;
}
export interface IWatcher {
    id: number;
    options?: {
        excludes?: string[];
    };
    disposable: IDisposable;
}
export declare class DiskFileSystemProvider extends RPCService<IRPCDiskFileSystemProvider> implements IDiskFileProvider {
    private fileChangeEmitter;
    private watcherServer;
    readonly onDidChangeFile: Event<FileChangeEvent>;
    protected watcherServerDisposeCollection: DisposableCollection;
    protected readonly watcherCollection: Map<string, IWatcher>;
    protected watchFileExcludes: string[];
    private _whenReadyDeferred;
    private isInitialized;
    private readonly injector;
    private readonly loggerManager;
    private logger;
    private ignoreNextChangesEvent;
    private recursive;
    constructor(recursive?: boolean);
    get whenReady(): Promise<void>;
    onDidChangeCapabilities: Event<void>;
    protected _capabilities: FileSystemProviderCapabilities | undefined;
    get capabilities(): FileSystemProviderCapabilities;
    dispose(): void;
    /**
     * @param {Uri} uri
     * @param {{ excludes: string[] }}
     * @memberof DiskFileSystemProvider
     */
    watch(uri: UriComponents, options?: {
        excludes?: string[];
    }): Promise<number>;
    unwatch(watcherId: number): void;
    stat(uri: UriComponents, options?: IFileStatOptions): Promise<FileStat>;
    readDirectory(uri: UriComponents): Promise<[string, FileType][]>;
    createDirectory(uri: UriComponents): Promise<FileStat>;
    readFile(uri: UriComponents, encoding?: string): Promise<Uint8Array>;
    readFileStream(uri: UriComponents, opts: IReadFileStreamOptions): Promise<Readable>;
    protected handleReadFileError(error: Error, uri: UriComponents): never;
    writeFile(uri: UriComponents, content: Uint8Array, options: {
        create: boolean;
        overwrite: boolean;
        encoding?: string;
    }): Promise<void | FileStat>;
    access(uri: UriComponents, mode?: number): Promise<boolean>;
    delete(uri: UriComponents, options: {
        recursive?: boolean;
        moveToTrash?: boolean;
    }): Promise<void>;
    rename(sourceUri: UriComponents, targetUri: UriComponents, options: {
        overwrite: boolean;
    }): Promise<FileStat>;
    copy(sourceUri: UriComponents, targetUri: UriComponents, options: {
        overwrite: boolean;
    }): Promise<FileStat>;
    getCurrentUserHome(): Promise<FileStat | undefined>;
    setWatchFileExcludes(excludes: string[]): void;
    getWatchFileExcludes(): string[];
    getWatchExcludes(excludes?: string[]): string[];
    protected initWatchServer(excludes?: string[]): void;
    private rewatch;
    protected createFile(uri: UriComponents, options: {
        content: Buffer;
    }): Promise<FileStat>;
    /**
     * Return `true` if it's possible for this URI to have children.
     * It might not be possible to be certain because of permission problems or other filesystem errors.
     */
    protected mayHaveChildren(uri: Uri): Promise<boolean>;
    protected doMove(sourceUri: UriComponents, targetUri: UriComponents, options: FileMoveOptions): Promise<FileStat>;
    protected doGetStat(uri: Uri, depth: number, options?: IFileStatOptions): Promise<FileStat | undefined>;
    protected doCreateFileStat(uri: Uri, stat: fse.Stats): Promise<FileStat>;
    protected getFileStatType(stat: fse.Stats): FileType;
    protected doCreateDirectoryStat(uri: Uri, stat: fse.Stats, depth: number): Promise<FileStat>;
    protected doGetChildren(uri: Uri, depth: number): Promise<FileStat[]>;
    getFileType(uri: string): Promise<string | undefined>;
}
//# sourceMappingURL=disk-file-system.provider.d.ts.map