"use strict";
/** ******************************************************************************
 * Copyright (C) 2018 TypeFox and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileChangeCollection = void 0;
// Some code copied and modified from https://github.com/eclipse-theia/theia/tree/v1.14.0/packages/filesystem/src/node/file-change-collection.ts
const common_1 = require("../common");
/**
 * A file change collection guarantees that only one change is reported for each URI.
 *
 * Changes are normalized according following rules:
 * - ADDED + ADDED => ADDED
 * - ADDED + UPDATED => ADDED
 * - ADDED + DELETED => NONE
 * - UPDATED + ADDED => UPDATED
 * - UPDATED + UPDATED => UPDATED
 * - UPDATED + DELETED => DELETED
 * - DELETED + ADDED => UPDATED
 * - DELETED + UPDATED => UPDATED
 * - DELETED + DELETED => DELETED
 */
class FileChangeCollection {
    constructor() {
        this.changes = new Map();
    }
    push(change) {
        const current = this.changes.get(change.uri);
        if (current) {
            if (this.isDeleted(current, change)) {
                this.changes.delete(change.uri);
            }
            else if (this.isUpdated(current, change)) {
                current.type = common_1.FileChangeType.UPDATED;
            }
            else if (!this.shouldSkip(current, change)) {
                current.type = change.type;
            }
        }
        else {
            this.changes.set(change.uri, change);
        }
    }
    isDeleted(current, change) {
        return current.type === common_1.FileChangeType.ADDED && change.type === common_1.FileChangeType.DELETED;
    }
    isUpdated(current, change) {
        return current.type === common_1.FileChangeType.DELETED && change.type === common_1.FileChangeType.ADDED;
    }
    shouldSkip(current, change) {
        return ((current.type === common_1.FileChangeType.ADDED && change.type === common_1.FileChangeType.UPDATED) ||
            (current.type === common_1.FileChangeType.UPDATED && change.type === common_1.FileChangeType.ADDED));
    }
    values() {
        return Array.from(this.changes.values());
    }
}
exports.FileChangeCollection = FileChangeCollection;
//# sourceMappingURL=file-change-collection.js.map